# Step 1 - Project Setup

Create a new repository and virtualenvironment to experiment with the orchestrator-core. Follow the steps below.

#### Step 1 a

<div class="termy">
```console
$ mkdir hello-world-orchestrator
$ cd hello-world-orchestrator
$ git init
$ git commit -am "Initial commit"
$ mkvirtualenv -p python3.9 hello-world-orchestrator
$ workon hello-world-orchestrator
```
</div>

#### Step 1 b
Follow the instructions laid out [here](../../base)
